@@ -31,6 +31,14 @@ class Auth:
         username = settings.get("username")
         return Atlassian(username, token)
 
+    def aws(self):
+        """Return an authorized AWS session."""
+        from bits.gaia.aws import AWS
+        settings = self.gaia.get_settings("aws")
+        access_key_id = settings.get("access_key_id")
+        secret_access_key = self.gaia.get_secret(settings.get("secret_access_key_name"))
+        return AWS(access_key_id, secret_access_key)
+
     def bitsdb_mongo(self):
         """Return an authorized Mongo instance for BITSdb."""
         from bits.mongo import Mongo
@@ -153,6 +161,13 @@ class Auth:
             verbose=self.gaia.verbose,
         )
 
+    def sendgrid(self):
+        """Return an authorized Sendgrid instance."""
+        from bits.gaia.sendgrid import SendGrid
+        settings = self.gaia.get_settings("sendgrid")
+        api_key = self.gaia.get_secret(settings.get("api_key_name"))
+        return SendGrid(api_key=api_key)
+
     def slack_admin_user(self):
         """Return an authorized Slack Admin instance with a user token."""
         from bits.gaia.slack import Slack
@@ -160,8 +175,29 @@ class Auth:
         token = self.gaia.get_secret(settings.get("user_token_name"))
         return Slack(token=token)
 
+    def slack_broadbits_bot(self):
+        """Return an authorized broadbits Slack Workspace instance with a bot token."""
+        from bits.gaia.slack import Slack
+        settings = self.gaia.get_settings("slack_broadbits")
+        token = self.gaia.get_secret(settings.get("bot_token_name"))
+        return Slack(token=token)
+
+    def slack_broadbits_user(self):
+        """Return an authorized broadbits Slack Workspace instance with a user token."""
+        from bits.gaia.slack import Slack
+        settings = self.gaia.get_settings("slack_broadbits")
+        token = self.gaia.get_secret(settings.get("user_token_name"))
+        return Slack(token=token)
+
+    def slack_broadinstitute_bot(self):
+        """Return an authorized broadinstitute Slack Workspace instance with a bot token."""
+        from bits.gaia.slack import Slack
+        settings = self.gaia.get_settings("slack_broadinstitute")
+        token = self.gaia.get_secret(settings.get("bot_token_name"))
+        return Slack(token=token)
+
     def slack_broadinstitute_user(self):
-        """Return an authorized Slack Workspace instance with a user token."""
+        """Return an authorized broadinstitute Slack Workspace instance with a user token."""
         from bits.gaia.slack import Slack
         settings = self.gaia.get_settings("slack_broadinstitute")
         token = self.gaia.get_secret(settings.get("user_token_name"))
